@@ -34,7 +34,7 @@
 namespace Oxygen
 {
 
-    //! QSplitter animation engine
+    //* QSplitter animation engine
     class SplitterEngine: public BaseEngine
     {
 
@@ -42,46 +42,42 @@ namespace Oxygen
 
         public:
 
-        //! constructor
+        //* constructor
         explicit SplitterEngine( QObject* parent ):
             BaseEngine( parent )
         {}
 
-        //! destructor
-        virtual ~SplitterEngine( void )
-        {}
-
-        //! enability
-        void setEnabled( bool value )
+        //* enable state
+        void setEnabled( bool value ) override
         {
             BaseEngine::setEnabled( value );
             _data.setEnabled( value );
         }
 
-        //! duration
-        void setDuration( int value )
+        //* duration
+        void setDuration( int value ) override
         {
             BaseEngine::setDuration( value );
             _data.setDuration( value );
         }
 
-        //! register widget
-        virtual bool registerWidget( QWidget* );
+        //* register widget
+        bool registerWidget( QWidget* );
 
-        //! true if widget hover state is changed
-        virtual bool updateState( const QPaintDevice*, bool );
+        //* true if widget hover state is changed
+        bool updateState( const QPaintDevice*, bool );
 
-        //! true if widget is animated
-        virtual bool isAnimated( const QPaintDevice* );
+        //* true if widget is animated
+        bool isAnimated( const QPaintDevice* );
 
-        //! animation opacity
-        virtual qreal opacity( const QPaintDevice* object )
+        //* animation opacity
+        qreal opacity( const QPaintDevice* object )
         { return isAnimated( object ) ? data( object ).data()->opacity(): AnimationData::OpacityInvalid; }
 
         public Q_SLOTS:
 
-        //! remove widget from map
-        bool unregisterWidget( QObject* data )
+        //* remove widget from map
+        bool unregisterWidget( QObject* data ) override
         {
 
             if( !data ) return false;
@@ -92,21 +88,19 @@ namespace Oxygen
 
         }
 
-        protected:
+        private:
 
-        //! returns data associated to widget
+        //* returns data associated to widget
         PaintDeviceDataMap<WidgetStateData>::Value data( const QPaintDevice* object )
         { return _data.find( object ).data(); }
 
-        private:
-
-        //! engine enability
+        //* engine enable state
         bool _enabled;
 
-        //! animation duration
+        //* animation duration
         int _duration;
 
-        //! map
+        //* map
         PaintDeviceDataMap<WidgetStateData> _data;
 
     };
