@@ -108,10 +108,6 @@ namespace Oxygen
 
     }
 
-    //_______________________________________________
-    AnimationConfigWidget::~AnimationConfigWidget( void )
-    {}
-
     //_______________________________________________
     void AnimationConfigWidget::load( void )
     {
