@@ -41,37 +41,34 @@ namespace Oxygen
 
         public:
 
-        //! constructor
+        //* constructor
         explicit AnimationConfigWidget( QWidget* = 0 );
 
-        //! destructor
-        virtual ~AnimationConfigWidget( void );
-
         public Q_SLOTS:
 
-        //! read current configuration
-        void load( void ) ;
+        //* read current configuration
+        void load( void ) override;
 
-        //! save current configuration
-        void save( void ) ;
+        //* save current configuration
+        void save( void ) override;
 
         protected Q_SLOTS:
 
-        //! check whether configuration is changed and emit appropriate signal if yes
-        void updateChanged() ;
+        //* check whether configuration is changed and emit appropriate signal if yes
+        void updateChanged() override;
 
         private:
 
-        GenericAnimationConfigItem* _genericAnimations;
-        GenericAnimationConfigItem* _progressBarAnimations;
-        GenericAnimationConfigItem* _progressBarBusyAnimations;
-        GenericAnimationConfigItem* _stackedWidgetAnimations;
-        GenericAnimationConfigItem* _labelAnimations;
-        GenericAnimationConfigItem* _lineEditAnimations;
-        GenericAnimationConfigItem* _comboBoxAnimations;
-        FollowMouseAnimationConfigItem* _toolBarAnimations;
-        FollowMouseAnimationConfigItem* _menuBarAnimations;
-        FollowMouseAnimationConfigItem* _menuAnimations;
+        GenericAnimationConfigItem* _genericAnimations = nullptr;
+        GenericAnimationConfigItem* _progressBarAnimations = nullptr;
+        GenericAnimationConfigItem* _progressBarBusyAnimations = nullptr;
+        GenericAnimationConfigItem* _stackedWidgetAnimations = nullptr;
+        GenericAnimationConfigItem* _labelAnimations = nullptr;
+        GenericAnimationConfigItem* _lineEditAnimations = nullptr;
+        GenericAnimationConfigItem* _comboBoxAnimations = nullptr;
+        FollowMouseAnimationConfigItem* _toolBarAnimations = nullptr;
+        FollowMouseAnimationConfigItem* _menuBarAnimations = nullptr;
+        FollowMouseAnimationConfigItem* _menuAnimations = nullptr;
 
     };
 
