@@ -28,7 +28,6 @@
 //////////////////////////////////////////////////////////////////////////////
 
 #include "oxygenframeshadow.h"
-#include "oxygenframeshadow.moc"
 
 #include <QDebug>
 #include <QAbstractScrollArea>
@@ -282,7 +281,7 @@ namespace Oxygen
 
         // grab viewport widget
         QWidget *viewport( FrameShadowBase::viewport() );
-        if( !viewport && parentWidget() && parentWidget()->inherits( "Q3ListView" ) )
+        if( !viewport && parentWidget() )
         { viewport = parentWidget(); }
 
         // set cursor from viewport
