@@ -30,9 +30,7 @@ namespace Oxygen
 
         Q_OBJECT
 
-        #if QT_VERSION >= 0x050000
         Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QStyleFactoryInterface" FILE "oxygen.json" )
-        #endif
 
         public:
 
